==> queueshare-0.0.55.tgz: package/src/qcSkipBack.js <==
import QcQueueIsPlaying from './QcQueueIsPlaying.js'
import qcSkipBackMap from './qcSkipBackMap.js'
import QcSkipBackPositions from './QcSkipBackPositions.js'
import CollabPosition from './CollabPosition.js'
import qcQueueMap from './qcQueueMap.js'
import QcQueuePositions from './QcQueuePositions.js'
import qcsCollabMap from './qcsCollabMap.js'

const qcSkipBack = () => {
	const queuePositions = QcQueuePositions()
	const currentTrackOrNull = queuePositions.length ? qcQueueMap.get(queuePositions[0]).track : null
	const currentPlaylistOrUndefined = queuePositions.length ? qcQueueMap.get(queuePositions[0]).playlist : undefined
	const skipBackValues = QcSkipBackPositions().map((position) => {
		return qcSkipBackMap.get(position)
	})
	for (let i = skipBackValues.length - 1; i >= 0; i--) {
		const previousTrack = skipBackValues[i].track
		const previousPlaylistOrUndefined = skipBackValues[i].playlist
		if (currentTrackOrNull !== previousTrack || currentPlaylistOrUndefined !== previousPlaylistOrUndefined) {
			if (queuePositions.length === 0) {
				QcQueueIsPlaying.set(false)
			}
			const skipBackInfo = JSON.parse(qcsCollabMap.get(previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-skipBackInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-skipBackInfo'))
			qcsCollabMap.delete(previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-skipBackInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-skipBackInfo')
			qcsCollabMap.set(
				previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-queueInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-queueInfo',
				JSON.stringify({...skipBackInfo, position: CollabPosition(null, queuePositions.length === 0 ? null : queuePositions[0])}),
			)
			return true
		}
	}
	return false
}

export default qcSkipBack

==> queueshare-0.0.57.tgz: package/src/qcSkipBack.js <==
import QcQueueIsPlaying from './QcQueueIsPlaying.js'
import qcPlayHistoryMap from './qcPlayHistoryMap.js'
import QcPlayHistoryPositions from './QcPlayHistoryPositions.js'
import CollabPosition from './CollabPosition.js'
import qcQueueMap from './qcQueueMap.js'
import QcQueuePositions from './QcQueuePositions.js'
import qcsCollabMap from './qcsCollabMap.js'

const qcSkipBack = () => {
	const queuePositions = QcQueuePositions()
	const currentTrackOrNull = queuePositions.length ? qcQueueMap.get(queuePositions[0]).track : null
	const currentPlaylistOrUndefined = queuePositions.length ? qcQueueMap.get(queuePositions[0]).playlist : undefined
	const skipBackValues = QcPlayHistoryPositions().map((position) => {
		return qcPlayHistoryMap.get(position)
	})
	for (let i = skipBackValues.length - 1; i >= 0; i--) {
		const previousTrack = skipBackValues[i].track
		const previousPlaylistOrUndefined = skipBackValues[i].playlist
		if (currentTrackOrNull !== previousTrack || currentPlaylistOrUndefined !== previousPlaylistOrUndefined) {
			if (queuePositions.length === 0) {
				QcQueueIsPlaying.set(false)
			}
			const skipBackInfo = JSON.parse(qcsCollabMap.get(previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-skipBackInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-skipBackInfo'))
			qcsCollabMap.delete(previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-skipBackInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-skipBackInfo')
			qcsCollabMap.set(
				previousPlaylistOrUndefined === undefined ? 'media-' + previousTrack + '-queueInfo' : 'media-' + previousTrack + '-playlists-' + previousPlaylistOrUndefined + '-queueInfo',
				JSON.stringify({...skipBackInfo, position: CollabPosition(null, queuePositions.length === 0 ? null : queuePositions[0])}),
			)
			return true
		}
	}
	return false
}

export default qcSkipBack
